summaryrefslogtreecommitdiff
path: root/chromium/third_party/blink/renderer/modules/peerconnection/adapters/quic_stream_proxy.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2019-02-13 15:05:36 +0100
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2019-02-14 10:33:47 +0000
commite684a3455bcc29a6e3e66a004e352dea4e1141e7 (patch)
treed55b4003bde34d7d05f558f02cfd82b2a66a7aac /chromium/third_party/blink/renderer/modules/peerconnection/adapters/quic_stream_proxy.h
parent2b94bfe47ccb6c08047959d1c26e392919550e86 (diff)
downloadqtwebengine-chromium-e684a3455bcc29a6e3e66a004e352dea4e1141e7.tar.gz
BASELINE: Update Chromium to 72.0.3626.110 and Ninja to 1.9.0
Change-Id: Ic57220b00ecc929a893c91f5cc552f5d3e99e922 Reviewed-by: Michael BrĂ¼ning <michael.bruning@qt.io>
Diffstat (limited to 'chromium/third_party/blink/renderer/modules/peerconnection/adapters/quic_stream_proxy.h')
-rw-r--r--chromium/third_party/blink/renderer/modules/peerconnection/adapters/quic_stream_proxy.h19
1 files changed, 12 insertions, 7 deletions
diff --git a/chromium/third_party/blink/renderer/modules/peerconnection/adapters/quic_stream_proxy.h b/chromium/third_party/blink/renderer/modules/peerconnection/adapters/quic_stream_proxy.h
index 0d059f635f6..5881aef8e0b 100644
--- a/chromium/third_party/blink/renderer/modules/peerconnection/adapters/quic_stream_proxy.h
+++ b/chromium/third_party/blink/renderer/modules/peerconnection/adapters/quic_stream_proxy.h
@@ -9,6 +9,7 @@
#include "base/memory/weak_ptr.h"
#include "base/single_thread_task_runner.h"
#include "base/threading/thread_checker.h"
+#include "third_party/blink/renderer/platform/wtf/vector.h"
namespace blink {
@@ -43,8 +44,10 @@ class QuicStreamProxy final : public base::SupportsWeakPtr<QuicStreamProxy> {
// Called when the remote side resets the stream.
virtual void OnRemoteReset() {}
- // Called when the remote side finishes the stream.
- virtual void OnRemoteFinish() {}
+ // Called when the remote side receives data and/or the finish bit.
+ virtual void OnDataReceived(Vector<uint8_t> data, bool fin) {}
+ // Called when data written with WriteData() has been consumed by QUIC.
+ virtual void OnWriteDataConsumed(uint32_t amount) {}
};
QuicStreamProxy();
@@ -67,7 +70,8 @@ class QuicStreamProxy final : public base::SupportsWeakPtr<QuicStreamProxy> {
scoped_refptr<base::SingleThreadTaskRunner> host_thread() const;
void Reset();
- void Finish();
+ void MarkReceivedDataConsumed(uint32_t amount);
+ void WriteData(Vector<uint8_t> data, bool fin);
private:
// Instruct the QuicTransportProxy to remove and delete this stream proxy.
@@ -76,7 +80,8 @@ class QuicStreamProxy final : public base::SupportsWeakPtr<QuicStreamProxy> {
// Callbacks from QuicStreamHost.
friend class QuicStreamHost;
void OnRemoteReset();
- void OnRemoteFinish();
+ void OnDataReceived(Vector<uint8_t> data, bool fin);
+ void OnWriteDataConsumed(uint32_t amount);
// Up reference. Owned by the QuicTransportProxy client.
QuicTransportProxy* transport_proxy_ = nullptr;
@@ -85,10 +90,10 @@ class QuicStreamProxy final : public base::SupportsWeakPtr<QuicStreamProxy> {
// Back reference. Owned by the RTCQuicTransport.
Delegate* delegate_ = nullptr;
// |readable_| transitions to false when OnRemoteFinish() is called.
bool readable_ = true;
- // |writeable_| transitions to false when Finish() is called.
- bool writeable_ = true;
+ // |writable_| transitions to false when WriteData(_, true) is called.
+ bool writable_ = true;
THREAD_CHECKER(thread_checker_);
};
@@ -85,10 +90,10 @@ class QuicStreamProxy final : public base::SupportsWeakPtr<QuicStreamProxy> {
// Back reference. Owned by the RTCQuicTransport.
Delegate* delegate_ = nullptr;
- // |readable_| transitions to false when OnRemoteFinish() is called.
+ // |readable_| transitions to false when OnDataReceived(_, true) is called.
bool readable_ = true;